@@ -3,7 +3,8 @@
 
 import os
 import zc.recipe.egg
-import zc.buildout.easy_install
+from zc.buildout import easy_install
+
 
 class Recipe(object):
     """This recipe is used by zc.buildout"""
@@ -28,14 +29,20 @@ class Recipe(object):
                     if x]
         modules = [x for x in options.get('modules', '').split('\n')
                    if x]
+        extrapaths = [x for x in options.get('extra-paths', '').split('\n')
+                   if x]
         scr = os.path.join(options['bin-directory'], options['zope2part'])
 
-        return zc.buildout.easy_install.scripts(
+        exitwithstatus = options.get('exit-with-status', False)
+        if exitwithstatus == 'true':
+            exitwithstatus = True
+
+        return easy_install.scripts(
             [(self.name, options['recipe']+'.ctl', 'run')],
             ws,
             options['executable'],
             options['bin-directory'],
-            arguments = [scr, packages, modules],
+            arguments = [scr, packages, modules, extrapaths, exitwithstatus],
             )
 
     def update(self):
